# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['eindhoven']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'pyproj>=3.3.1,<4.0.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'eindhoven',
    'version': '3.1.0',
    'description': 'Asynchronous Python client providing Open Data information of Eindhoven',
    'long_description': '<!-- Banner -->\n![alt Banner of the eindhoven package](assets/header_eindhoven-min.png)\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![PyPi Downloads][downloads-shield]][downloads-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![Code Coverage][codecov-shield]][codecov-url]\n\n[![Build Status][build-shield]][build-url]\n[![Typing Status][typing-shield]][typing-url]\n\nAsynchronous Python client for the open datasets of Eindhoven (The Netherlands).\n\n## About\n\nA python package with which you can retrieve data from the Open Data Platform of Eindhoven via [their API][api]. This package was initially created to only retrieve parking data from the API, but the code base is made in such a way that it is easy to extend for other datasets from the same platform.\n\n## Installation\n\n```bash\npip install eindhoven\n```\n\n## Datasets\n\nYou can read the following datasets with this package:\n\n- [Parking spots / Parkeerplaatsen][parking]\n\n<details>\n    <summary>Click here to get more details</summary>\n\n### Parkings spots\n\nYou can use the following parameters in your request:\n\n- **limit** (default: 10) - How many results you want to retrieve.\n- **parking_type** (default: 1) - See the list below to find the corresponding number.\n\n| parking_type | number |\n| :----------- | :----: |\n| Parkeerplaats | 1 |\n| Parkeerplaats Vergunning | 2 |\n| Parkeerplaats Gehandicapten | 3 |\n| Parkeerplaats Afgekruist | 4 |\n| Parkeerplaats laden/lossen | 5 |\n| Parkeerplaats Electrisch opladen | 6 |\n\nYou get the following output data back with this python package:\n\n| Variable | Type | Description |\n| :------- | :--- | :---------- |\n| `spot_id` | string | The id of the parking spot |\n| `parking_type` | string | The type of parking of the parking spot |\n| `street` | string | The street name where this parking spot is located |\n| `number` | int | The number of parkings spots on this location |\n| `longitude` | float | The longitude of the parking spot |\n| `latitude` | float | The latitude of the parking spot |\n| `updated_at` | datetime | When this parking spot was updated in the dataset |\n</details>\n\n### Example\n\n```python\nimport asyncio\n\nfrom eindhoven import ODPEindhoven\n\n\nasync def main() -> None:\n    """Show example on using the Open Data Platform API of Eindhoven."""\n    async with ODPEindhoven() as client:\n        locations = await client.locations(limit=100, parking_type=4)\n        print(locations)\n\n\nif __name__ == "__main__":\n    asyncio.run(main())\n```\n\n## Use cases\n\n[NIPKaart.nl][nipkaart]\n\nA website that provides insight into where disabled parking spaces are, based on data from users and municipalities. Operates mainly in the Netherlands, but also has plans to process data from abroad.\n\n## Contributing\n\nThis is an active open-source project. We are always open to people who want to\nuse the code or contribute to it.\n\nWe\'ve set up a separate document for our\n[contribution guidelines](CONTRIBUTING.md).\n\nThank you for being involved! :heart_eyes:\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependency\nmanager.\n\nYou need at least:\n\n- Python 3.9+\n- [Poetry][poetry-install]\n\nInstall all packages, including all development requirements:\n\n```bash\npoetry install\n```\n\nPoetry creates by default an virtual environment where it installs all\nnecessary pip packages, to enter or exit the venv run the following commands:\n\n```bash\npoetry shell\nexit\n```\n\nSetup the pre-commit check, you must run this inside the virtual environment:\n\n```bash\npre-commit install\n```\n\n*Now you\'re all set to get started!*\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2020-2022 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n[api]: https://data.eindhoven.nl\n[parking]: https://data.eindhoven.nl/explore/dataset/parkeerplaatsen/information\n[nipkaart]: https://www.nipkaart.nl\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[build-shield]: https://github.com/klaasnicolaas/python-eindhoven/actions/workflows/tests.yaml/badge.svg\n[build-url]: https://github.com/klaasnicolaas/python-eindhoven/actions/workflows/tests.yaml\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-eindhoven.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-eindhoven/context:python\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-eindhoven.svg\n[commits-url]: https://github.com/klaasnicolaas/python-eindhoven/commits/main\n[codecov-shield]: https://codecov.io/gh/klaasnicolaas/python-eindhoven/branch/main/graph/badge.svg?token=4AMI23ZT7C\n[codecov-url]: https://codecov.io/gh/klaasnicolaas/python-eindhoven\n[downloads-shield]: https://img.shields.io/pypi/dm/eindhoven\n[downloads-url]: https://pypistats.org/packages/eindhoven\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-eindhoven.svg\n[issues-url]: https://github.com/klaasnicolaas/python-eindhoven/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-eindhoven.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-eindhoven.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2022.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/c577da6bb1b3bb6553bd/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-eindhoven/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-production%20ready-brightgreen.svg\n[pypi]: https://pypi.org/project/eindhoven/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/eindhoven\n[typing-shield]: https://github.com/klaasnicolaas/python-eindhoven/actions/workflows/typing.yaml/badge.svg\n[typing-url]: https://github.com/klaasnicolaas/python-eindhoven/actions/workflows/typing.yaml\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-eindhoven.svg\n[releases]: https://github.com/klaasnicolaas/python-eindhoven/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-eindhoven.svg\n[stars-url]: https://github.com/klaasnicolaas/python-eindhoven/stargazers\n\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-eindhoven',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
